@@ -161,6 +161,9 @@ GBLtranslators =
 "Rafael Carreras\n"
 "- ca (Catalan) translation of ISO Master version 1.1\n"
 "\n"
+"Josep Sanchez Mesegue\n"
+"- ca (Catalan) translation of ISO Master version 1.2\n"
+"\n"
 "Schmaki\n"
 "- cs (Czech) translation of ISO Master version 1.1\n"
 "\n"
@@ -173,6 +176,9 @@ GBLtranslators =
 "Magnus Valle\n"
 "- da (Danish) translation of ISO Master version 1.3\n"
 "\n"
+"Henrik Kristiansen\n"
+"- da (Danish) translation of ISO Master version 1.3\n"
+"\n"
 "Mike Kranidis\n"
 "- el (Greek) translation of ISO Master versions 1.1 - 1.3\n"
 "\n"
@@ -219,7 +225,10 @@ GBLtranslators =
 "- it (Italian) translation of ISO Master version 0.7 - 1.0\n"
 "\n"
 "Valerio Guaglianone\n"
-"- it (Italian) translation of ISO Master version 0.7, 1.1, 1.6\n"
+"- it (Italian) translation of ISO Master version 0.7, 1.1, 1.3\n"
+"\n"
+"Rihards Prieditis\n"
+"- lv (Latvian) translation of ISO Master version 1.3\n"
 "\n"
 "Robert Groenning\n"
 "- nb (Norwegian Bokmal) translation of ISO Master version 1.0\n"
@@ -227,6 +236,9 @@ GBLtranslators =
 "Stephen Brandt\n"
 "- nl (Dutch) translation of ISO Master versions 0.7 - 1.3\n"
 "\n"
+"Kristof Bal\n"
+"- nl (Dutch) translation of ISO Master version 1.3\n"
+"\n"
 "Robert Groenning\n"
 "- nn (Norwegian Nynorsk) translation of ISO Master version 1.1\n"
 "\n"
@@ -237,7 +249,7 @@ GBLtranslators =
 "- pt (Portuguese) translation of ISO Master versions 0.8, 1.0\n"
 "\n"
 "Antonio Sousa\n"
-"- pt (Portuguese) translation of ISO Master version 1.6\n"
+"- pt (Portuguese) translation of ISO Master version 1.3\n"
 "\n"
 "Alexandre Marques\n"
 "- pt_BR (Portuguese/Brasil) translation of ISO Master version 1.3\n"
@@ -267,10 +279,7 @@ GBLtranslators =
 "- sv (Swedish) translation of ISO Master version 1.1\n"
 "\n"
 "Tutku Dalmaz\n"
-"- tr (Turkish) translation of ISO Master version 1.0\n"
-"\n"
-"Tutku Dalmaz\n"
-"- tr (Turkish) translation of ISO Master version 1.0\n"
+"- tr (Turkish) translation of ISO Master version 1.0. 1.3\n"
 "\n"
 "Serhey Kusyumoff\n"
 "- uk (Ukrainian) translation of ISO Master versions 0.8, 1.3\n"
